@@ -43,7 +43,7 @@ char *filename1, *filename2;
   char *cp;
 
   strcpy(filename3, filename1);
-  cp = strrchr(filename3, '/');
+  cp = (char *) strrchr(filename3, '/');
   if (cp)
     cp++;
   else
