@@ -394,7 +394,7 @@ ne_nexrec *nex, **newnex;
   for (i = 0; i < FORLIM; i++)
     ne_copy(nex->UU.U99.pvals[i], &(*newnex)->UU.U99.pvals[i]);
   if (op == ne_sc)
-    nex->UU.s = strdup((*newnex)->UU.s);
+    nex->UU.s = (char *) strdup((*newnex)->UU.s);
 }
 
 
@@ -656,7 +656,7 @@ struct LOC_opt *LINK;
 {
   ne_dispose(LINK->nex);
   newnexrec(LINK->nex, 0L, ne_sc);
-  (*LINK->nex)->UU.s = strdup(res);
+  (*LINK->nex)->UU.s = (char *)strdup(res);
 }
 
 Local boolean istrue(nex, LINK)
@@ -796,7 +796,7 @@ struct LOC_optimize *LINK;
   case ne_sp:
     if (WITH->UU.U12.sps != NULL && makeconstant(WITH->UU.U12.sps->s, &V)) {
       WITH->op = (unsigned)ne_sc;
-      WITH->UU.s = strdup(*WITH->UU.U12.sp);
+      WITH->UU.s = (char *)strdup(*WITH->UU.U12.sp);
     }
     break;
 
@@ -1689,7 +1689,7 @@ struct LOC_expr *LINK;
 
     case ne_kind_strconst:
       nex = make2(ne_sc, NULL, NULL);
-      nex->UU.s = strdup((Char *)value);
+      nex->UU.s = (char *)strdup((Char *)value);
       break;
 
     case ne_kind_strvalue:
@@ -1928,7 +1928,7 @@ struct LOC_expr *LINK;
 	done = true;
     } while (!done);
     nex = make2(ne_sc, nex, NULL);
-    nex->UU.s = strdup(name);
+    nex->UU.s = (char *)strdup(name);
     if (allocdone) 
       na_free((Anyptr)&args);
     return nex;
@@ -3160,7 +3160,7 @@ ne_nexrec *nex, *res;
 
     case ne_string:
       res->op = (unsigned)ne_sc;
-      res->UU.s = strdup(ne_seval(STR1, nex));
+      res->UU.s = (char *)strdup(ne_seval(STR1, nex));
       break;
     }
   RECOVER(try14);
@@ -3365,7 +3365,7 @@ na_strlist *sym;
 Char *s;
 {
   sym->kind = ne_kind_strconst;
-  *(Char **)((Char **)(&sym->value)) = strdup(s);
+  *(Char **)((Char **)(&sym->value)) = (char *)strdup(s);
 }
 
 
