@@ -231,7 +231,7 @@ Char *fn;
   ENDTRY(try1);
   if (okay) {
     while (fgets(buf, 256, f) != NULL) {
-      TEMP = strchr(buf, '\n');
+      TEMP = (char *) strchr(buf, '\n');
       if (TEMP != NULL)
 	*TEMP = 0;
       plot_out(buf);
